<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  画像ファイル情報の取得
 *
 *  @access public
 *  @param  integer $image_id           ID
 */
function db_get_image($image_id)
{
    $sql = 'SELECT image_id, title, size, type, image, r_datetime' .
            ' FROM pbb_images' .
            ' WHERE image_id = ?';
    $params = array(
        intval($image_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  画像ファイル一覧情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_images4list($page = 1, $page_size = 5)
{
    $sql = 'SELECT image_id, title, size, type, r_datetime' .
            ' FROM pbb_images' .
            ' ORDER BY r_datetime DESC';
    return pocket_db_getAllPage($sql, $page, $page_size);
}

/**
 *  画像ファイル件数の取得
 *
 *  @access public
 */
function db_get_images_count4list()
{
    $sql = 'SELECT count(image_id)' .
            ' FROM pbb_images';
    return pocket_db_getOne($sql);
}

/**
 *  画像ファイル情報の登録
 *
 *  @access public
 *  @param  string  $title              タイトル
 *  @param  integer $size               ファイルサイズ
 *  @param  string  $type               ファイルの種類
 *  @param  binary  $image              画像データ
 */
function db_insert_image($title, $size, $type, $image)
{
    $data = array(
        'title' => $title,
        'size' => intval($size),
        'type' => $type,
        'image' => $image,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pbb_images', $data, 'pbb_images_image_id_seq');
}

/**
 *  画像ファイル情報の更新
 *
 *  @access public
 *  @param  integer $image_id           ID
 *  @param  string  $title              タイトル
 */
function db_update_image($image_id, $title)
{
    $data = array(
        'title' => $title
    );
    $where = array(
        'image_id' => intval($image_id)
    );
    return pocket_db_update('pbb_images', $data, $where);
}

/**
 *  画像ファイル情報の削除
 *
 *  @access public
 *  @param  integer $image_id           ID
 */
function db_delete_image($image_id)
{
    return pocket_db_delete('pbb_images', 'image_id', intval($image_id));
}

?>
